"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFormPromter = void 0;
/* eslint-disable no-alert */
const react_1 = __importStar(require("react"));
const words_1 = require("react-immutable-form/words");
const react_router_1 = require("react-router");
/**
 * Created a FormPromter component, given a history value
 *
 * @param {*} history The History value from react-router
 * @returns {JSX.Element | null} The FormPrompt component.
 */
const createFormPromter = (history) => {
    const useBlocker = (blocker, when = true) => {
        react_1.default.useEffect(() => {
            if (!when) {
                return () => { };
            }
            const unblock = history.block((tx) => {
                const autoUnblockingTx = Object.assign(Object.assign({}, tx), { retry() {
                        unblock();
                        tx.retry();
                    } });
                blocker(autoUnblockingTx);
            });
            return unblock;
        }, [blocker, when]);
    }, useCallbackPrompt = (when) => {
        const navigate = (0, react_router_1.useNavigate)(), location = (0, react_router_1.useLocation)(), [showPrompt, setShowPrompt] = (0, react_1.useState)(false), [lastLocation, setLastLocation] = (0, react_1.useState)(null), [confirmedNavigation, setConfirmedNavigation] = (0, react_1.useState)(false), cancelNavigation = (0, react_1.useCallback)(() => {
            setShowPrompt(false);
        }, []), handleBlockedNavigation = (0, react_1.useCallback)((nextLocation) => {
            const locationChanged = nextLocation.location.pathname !== location.pathname, didNotConfirmed = !confirmedNavigation, shouldPrompt = locationChanged && didNotConfirmed;
            if (shouldPrompt) {
                setShowPrompt(true);
                setLastLocation(nextLocation);
                return false;
            }
            return true;
        }, [confirmedNavigation]), confirmNavigation = (0, react_1.useCallback)(() => {
            setShowPrompt(false);
            setConfirmedNavigation(true);
        }, []);
        (0, react_1.useEffect)(() => {
            if (confirmedNavigation && lastLocation) {
                navigate(lastLocation.location.pathname);
            }
        }, [confirmedNavigation, lastLocation]);
        useBlocker(handleBlockedNavigation, when);
        return [showPrompt, confirmNavigation, cancelNavigation];
    }, 
    /**
   * FormPrompt component.
   *
   * This component monitors whether a form has unsaved changes and, if the user attempts to navigate away
   * from the form, it displays a confirmation prompt asking if they are sure they want to leave without saving.
   *
   * @param {Object} props - Component properties.
   * @param {boolean} props.dirty - Indicates whether the form has unsaved changes.
   *
   * @returns {JSX.Element | null} The FormPrompt component.
   */
    FormPrompt = (props) => {
        const [showPrompt, confirmNavigation, cancelNavigation] = useCallbackPrompt(props.dirty), [showConfirm, setShowConfirm] = react_1.default.useState(false);
        react_1.default.useEffect(() => {
            if (showPrompt && !showConfirm) {
                setShowConfirm(true);
                if (confirm((0, words_1.getWords)().CONFIRMATION_FORM_LEAVE)) {
                    if (typeof confirmNavigation === "function") {
                        confirmNavigation();
                    }
                }
                else if (typeof cancelNavigation === "function") {
                    setTimeout(() => {
                        cancelNavigation();
                        setShowConfirm(false);
                        // eslint-disable-next-line no-magic-numbers
                    }, 100);
                }
            }
        }, [showConfirm, showPrompt]);
        return (null);
    };
    return FormPrompt;
};
exports.createFormPromter = createFormPromter;
//# sourceMappingURL=FormPrompt.js.map